pub struct BookingReportResponse {
pub data: Vec<BookingReport>,
pub page: Page,
}Fields
data: Vec<BookingReport>page: PageTrait Implementations
Sourceimpl Clone for BookingReportResponse
impl Clone for BookingReportResponse
Sourcefn clone(&self) -> BookingReportResponse
fn clone(&self) -> BookingReportResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BookingReportResponse
impl Debug for BookingReportResponse
Sourceimpl<'de> Deserialize<'de> for BookingReportResponse
impl<'de> Deserialize<'de> for BookingReportResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BookingReportResponse
impl JsonSchema for BookingReportResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BookingReportResponse
impl PartialEq for BookingReportResponse
Sourceimpl Serialize for BookingReportResponse
impl Serialize for BookingReportResponse
impl StructuralPartialEq for BookingReportResponse